"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var ivy_angular_web_1 = require("ivy.angular.web");
var MaterialsWidthHelper = /** @class */ (function () {
    function MaterialsWidthHelper(windowRef) {
        this.windowRef = windowRef;
        // Doesn't appear we can use HostListener in a service correctly
        // http://stackoverflow.com/questions/39592972/is-it-possible-to-use-hostlistener-in-a-service
    }
    /*
     * All numbers for this service has been derived from the Materials Design Specification
     * They should accurately represent the Materials Design Interpretation of screen sizes
     * https://material.io/guidelines/layout/responsive-ui.html#responsive-ui-breakpoints
     *
     * xs: < 480px
     * sm: < 960px
     * md: < 1280px
     * lg: < 1920px
     * xl: > 1920px
     */
    MaterialsWidthHelper.prototype.isXs = function () {
        return this.isWindowUnderWidth(480);
    };
    MaterialsWidthHelper.prototype.isSm = function () {
        return this.isWindowBetween(480, 960);
    };
    MaterialsWidthHelper.prototype.isMd = function () {
        return this.isWindowBetween(960, 1280);
    };
    MaterialsWidthHelper.prototype.isLg = function () {
        return this.isWindowBetween(1280, 1920);
    };
    MaterialsWidthHelper.prototype.isXl = function () {
        return this.isWindowOverWidth(1920);
    };
    /*
     * The following items have been expanded based on some weirdness we're seeing with @angular/material
     * essentially, some of their breakpoints are operating outside of the above.  As such, attempts to identify
     * the above are not accurate enough.  To allow for us to hit all of the other ranges, appropriately,
     * these methods have been created based on the following:
     * https://material.io/design/layout/responsive-layout-grid.html#breakpoints
     */
    MaterialsWidthHelper.prototype.isBelow359 = function () {
        return this.isWindowUnderWidth(359);
    };
    MaterialsWidthHelper.prototype.is360to399 = function () {
        return this.isWindowBetween(359, 399);
    };
    MaterialsWidthHelper.prototype.is400to479 = function () {
        return this.isWindowBetween(399, 479);
    };
    MaterialsWidthHelper.prototype.is480to599 = function () {
        return this.isWindowBetween(479, 599);
    };
    MaterialsWidthHelper.prototype.is600to719 = function () {
        return this.isWindowBetween(599, 719);
    };
    MaterialsWidthHelper.prototype.is720to839 = function () {
        return this.isWindowBetween(719, 839);
    };
    MaterialsWidthHelper.prototype.is840to959 = function () {
        return this.isWindowBetween(839, 959);
    };
    MaterialsWidthHelper.prototype.is960to1023 = function () {
        return this.isWindowBetween(959, 1023);
    };
    MaterialsWidthHelper.prototype.is1024to1279 = function () {
        return this.isWindowBetween(1023, 1279);
    };
    MaterialsWidthHelper.prototype.is1280to1439 = function () {
        return this.isWindowBetween(1279, 1439);
    };
    MaterialsWidthHelper.prototype.is1440to1599 = function () {
        return this.isWindowBetween(1439, 1599);
    };
    MaterialsWidthHelper.prototype.is1600to1919 = function () {
        return this.isWindowBetween(1599, 1919);
    };
    MaterialsWidthHelper.prototype.isAbove1920 = function () {
        return this.isWindowOverWidth(1919);
    };
    MaterialsWidthHelper.prototype.isWindowUnderWidth = function (width) {
        return this.windowRef.nativeWindow.innerWidth <= width;
    };
    MaterialsWidthHelper.prototype.isWindowOverWidth = function (width) {
        return this.windowRef.nativeWindow.innerWidth > width;
    };
    MaterialsWidthHelper.prototype.isWindowBetween = function (lowWidth, highWidth) {
        return this.isWindowUnderWidth(highWidth) &&
            this.isWindowOverWidth(lowWidth);
    };
    MaterialsWidthHelper = __decorate([
        core_1.Injectable(),
        __metadata("design:paramtypes", [ivy_angular_web_1.WindowRefService])
    ], MaterialsWidthHelper);
    return MaterialsWidthHelper;
}());
exports.MaterialsWidthHelper = MaterialsWidthHelper;
//# sourceMappingURL=materials-width-helper.service.js.map